pub struct TerminateDepositOptions {
pub chain_name: String,
pub address: Option<Address>,
pub account_no: Option<usize>,
pub skip_check: bool,
pub deposit_id: Option<String>,
pub lock_contract: Option<Address>,
pub deposit_nonce: Option<u64>,
}Fields
chain_name: Stringaddress: Option<Address>account_no: Option<usize>skip_check: booldeposit_id: Option<String>lock_contract: Option<Address>deposit_nonce: Option<u64>Trait Implementations
Sourceimpl StructOpt for TerminateDepositOptions
impl StructOpt for TerminateDepositOptions
Sourcefn from_clap(matches: &ArgMatches<'_>) -> Self
fn from_clap(matches: &ArgMatches<'_>) -> Self
Builds the struct from
clap::ArgMatches. It’s guaranteed to succeed
if matches originates from an App generated by StructOpt::clap called on
the same type, otherwise it must panic.Sourcefn from_args() -> Selfwhere
Self: Sized,
fn from_args() -> Selfwhere
Self: Sized,
Builds the struct from the command line arguments (
std::env::args_os).
Calls clap::Error::exit on failure, printing the error message and aborting the program.Sourcefn from_args_safe() -> Result<Self, Error>where
Self: Sized,
fn from_args_safe() -> Result<Self, Error>where
Self: Sized,
Builds the struct from the command line arguments (
std::env::args_os).
Unlike StructOpt::from_args, returns clap::Error on failure instead of aborting the program,
so calling .exit is up to you.Sourcefn from_iter<I>(iter: I) -> Self
fn from_iter<I>(iter: I) -> Self
Gets the struct from any iterator such as a
Vec of your making.
Print the error message and quit the program in case of failure. Read moreAuto Trait Implementations
impl Freeze for TerminateDepositOptions
impl RefUnwindSafe for TerminateDepositOptions
impl Send for TerminateDepositOptions
impl Sync for TerminateDepositOptions
impl Unpin for TerminateDepositOptions
impl UnwindSafe for TerminateDepositOptions